{-----------------------------------------------------------------------------
 Unit Name: uAppointments
 Author:    Rob Bracken
 Purpose:   Collection of Appointment objects
 History:
-----------------------------------------------------------------------------}


unit uAppointments;

interface

uses
  uAppointment
  , contnrs
  , classes
  ;

type

  TAppointments = class(TObject)
  private

    FList: TObjectList;

    function GetCount: integer;
    function GetItem(Index: integer): TAppointment;
    procedure SetItem(Index: integer; Value: TAppointment);

  public

    constructor Create;
    destructor Destroy; override;

    function Add(AAppointment: TAppointment): Integer;
    procedure AddRandomAppointment(Who, WithWhom: TStringList);

    property Count: integer
      read GetCount;

    property Items[Index: Integer]: TAppointment
      read GetItem
      write SetItem;

  end;

implementation

uses
  sysutils
  ;

{ TAppointments }

function TAppointments.Add(AAppointment: TAppointment): Integer;
var
  nAppt: integer;
begin
  // Maintain the list sorted by date
  nAppt := 0;
  while (nAppt < Count) and
        (Items[nAppt].When <= AAppointment.When) do
    Inc(nAppt);
  FList.Insert(nAppt, AAppointment);
  Result := nAppt;
end;

procedure TAppointments.AddRandomAppointment(Who, WithWhom: TStringList);
var
  apptTemp: TAppointment;
  nMins: integer;
  nHours: integer;
begin
  // Create a random appointment & add it to our list
  apptTemp := TAppointment.Create;
  apptTemp.When := Now + (Random * 30);       // Some time in next 30 days
  apptTemp.Who := Who.Strings[Random(Who.Count)];     // Whose appointment is it?
  apptTemp.WithWhom := WithWhom.Strings[Random(WithWhom.Count)];     // Who is the appointment with?
  nMins := 15 * (Random(8) + 1);              // How many 1/4 hours?
  nHours := nMins div 60;                     // How many hours?
  nMins := nMins mod 60;                      // How many minutes?
  apptTemp.HowLong := EncodeTime(nHours, nMins, 0, 0);
  Self.Add(apptTemp);
end;

constructor TAppointments.Create;
begin
  inherited Create;
  FList := TObjectList.Create;
end;

destructor TAppointments.Destroy;
begin
  FList.Clear;
  FList.Free;
  inherited;
end;

function TAppointments.GetCount: integer;
begin
  Result := FList.Count;
end;

function TAppointments.GetItem(Index: integer): TAppointment;
begin
  Result := TAppointment(FList.Items[Index]);
end;

procedure TAppointments.SetItem(Index: integer; Value: TAppointment);
begin
  FList.Items[Index] := Value;
end;

end.
