{-----------------------------------------------------------------------------
 Unit Name: uApptNoneIterator
 Author:    Rob Bracken
 Purpose:   Appointments iterator that never returns any appointments
 History:
-----------------------------------------------------------------------------}


unit uApptNoneIterator;

interface

uses
  uIApptIterator
  , uAppointment
  ;

type

  TApptNoneIterator = class(TInterfacedObject, IApptIterator)
  private

    function First: TAppointment;
    function Last: TAppointment;
    function HasNext: boolean;
    function HasPrev: boolean;
    function Current: TAppointment;
    function Next: TAppointment;
    function Prev: TAppointment;

  public

    constructor Create;

  end;

implementation

uses
  uApptIterator
  ;

{ TApptNoneIterator }

constructor TApptNoneIterator.Create;
begin
  inherited Create;
end;

function TApptNoneIterator.Current: TAppointment;
begin
  Result := nil;
end;

function TApptNoneIterator.First: TAppointment;
begin
  Result := Current;
end;

function TApptNoneIterator.HasNext: boolean;
begin
  Result := False;
end;

function TApptNoneIterator.HasPrev: boolean;
begin
  Result := False;
end;

function TApptNoneIterator.Last: TAppointment;
begin
  Result := Current;
end;

function TApptNoneIterator.Next: TAppointment;
begin
  if HasNext then
  begin
    Result := Current;
  end
  else
  begin
    raise EApptIteratorException.Create('No more appointments');
  end;
end;

function TApptNoneIterator.Prev: TAppointment;
begin
  if HasPrev then
  begin
    Result := Current;
  end
  else
  begin
    raise EApptIteratorException.Create('No more appointments');
  end;
end;

end.
